

{ config,
  nixosConfig,
  pkgs,
  lib,
  inputs,
  home-manager,
  ... }:
{

  imports = [
     #inputs.nix-index-db.hmModules.nix-index
  ];

  home.packages = with pkgs; [
    steam
    networkmanagerapplet
    activitywatch
    ngspice
    hugo
    kicad
    okular
    mupdf
    libreoffice
    hunspell
    hunspellDicts.en_US
    cider
    foot
    prismlauncher
    firefox
    librewolf
    neomutt
    dunst
    pass
    isync
    msmtp
    notmuch
    kitty
    lynx
    playerctl
    nheko
    hyprpaper
    xdg-desktop-portal-hyprland
    pavucontrol
    slurp
    grim
    wofi
    imv
    swaylock-effects
    qt5ct
    qt6ct
    mpv
    #steamvr?
    procps
    usbutils
    (python311.withPackages (lib.attrVals ["sympy" "matplotlib"]))
    (octaveFull.withPackages (lib.attrVals ["symbolic"]))
  ];

  dconf.settings = {
    "org/virt-manager/virt-manager/connections" = {
      autoconnect = ["qemu:///system"];
      uris = ["qemu:///system"];
    };
  };


  home.sessionVariables = {
    FOO = "BAR";

  };

  #programs.hyprland.enable = true;
  # hyprland.homeManagerModules.default
  #wayland.windowManager.hyprland.enable = true;

  home.file = {
    ".zshrc".source = config.lib.file.mkOutOfStoreSymlink "/etc/nixos/config/zshrc";
  };

  xdg.configFile = { 
    "dunst" = {
      source = config.lib.file.mkOutOfStoreSymlink "/etc/nixos/config/dunst";
      recursive = true;
    };
    "eww" = {
      source = config.lib.file.mkOutOfStoreSymlink "/etc/nixos/config/eww";
      recursive = true;
    };
    "hypr" = {
      source = config.lib.file.mkOutOfStoreSymlink "/etc/nixos/config/hypr";
      recursive = true;
    };
    "swaylock" = {
      source = config.lib.file.mkOutOfStoreSymlink "/etc/nixos/config/swaylock";
      recursive = true;
    };
  };

  systemd.user.services = {
    mailsync = {
      Unit = {
        Description = "Syncs email";
	After = [ "network-online.target" ];
      };
      Service = {
        Type = "oneshot";
        ExecStart = "${pkgs.mutt-wizard}/bin/mailsync";
        Environment =  [
          "DBUS_SESSION_BUS_ADDRESS=unix:path=/run/user/1000/bus"
          "DISPLAY=:0"
          "MBSYNCRC=/home/stitchynyan/.config/mbsync/config"
          "PATH=$PATH:${lib.makeBinPath [ pkgs.busybox pkgs.cyrus-sasl-xoauth2 pkgs.gnupg pkgs.isync pkgs.notify pkgs.notmuch pkgs.pass pkgs.perl pkgs.python3 ]}"
          "SASL_PATH=/run/current-system/sw/lib/sasl2"
          "WAYLAND_DISPLAY=wayland-1"
        ];
      };
      Install.WantedBy = [ "default.target" ];
    };
  };

  systemd.user.timers = {
    mailsync = {
      Unit.Description = "Syncs email";
      Timer = {
        OnBootSec = "1min";
	OnUnitActiveSec = "10min";
      };
      Install.WantedBy = [ "timers.target" ];
    };
  };


  home.pointerCursor = {
    name = "phinger-cursors";
    package = pkgs.phinger-cursors;
    gtk.enable = true;
    size = 64;
  };
  
  # Read the Docs before change
  home.stateVersion = "23.05";
  home.homeDirectory = "/home/stitchynyan";
}
